@@ -11,6 +11,15 @@ def ocr_engine(filename):
     pass
   line_dir = 'output/'
   if '.pdf' in filename:
+    try:
+      f1 = open(filename)
+      text1 = f1.read()
+      if text1 is []:
+        pass
+      else:
+        return text
+    except:
+      pass
     try:
       os.mkdir(line_dir+'pdfout/')
     except:
